@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+    Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
     Copyright (c) 2008 Thomas McGuire <mcguire@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
@@ -221,9 +221,9 @@ void SignatureTester::testImages()
     QImage image1, image2;
     QVERIFY(image1.load(image1Path));
     QVERIFY(image2.load(image1Path));
-    QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QStringLiteral("emailidentities/unittest/");
+    QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/emailidentities/unittest/");
     QDir().mkpath(path);
-    QString configPath = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + QStringLiteral("signaturetest");
+    QString configPath = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QStringLiteral("/signaturetest");
     QDir().mkpath(configPath);
     KConfig config(configPath);
     KConfigGroup group1 = config.group("Signature1");
